Authentication reference
Kerberos, password, keytab, ipalib, ipa-getkeytab, and execution-environment dependencies.
Facts
- IdM JSON-RPC inventory can use password authentication or Kerberos with an optional keytab.
- ipalib-backed lookups and modules require IdM client Python libraries on the control node or execution environment.
- Keytab lookup and keytab management use platform tooling that provides
ipa-getkeytab. - AAP use should package these dependencies into a controlled execution environment.